@@ -3,7 +3,8 @@ from pathlib import Path
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
 
-from scanpydoc.rtd_github_links import github_url, _get_linenos, _get_obj_module
+from scanpydoc.rtd_github_links import _get_linenos, _get_obj_module, github_url
+
 
 HERE = Path(__file__).parent
 
@@ -24,8 +25,8 @@ def test_as_function(env):
 
 
 def test_get_obj_module():
-    import sphinx.application
+    import get_version
 
-    obj, mod = _get_obj_module("sphinx.application.Sphinx")
-    assert obj is sphinx.application.Sphinx
-    assert mod is sphinx.application
+    obj, mod = _get_obj_module("scanpydoc.get_version")
+    assert obj is get_version.get_version
+    assert mod is get_version
